==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ArcGISOnlineMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { ArcGISOnlineMapImageryDescription } from "./ArcGISOnlineMapImageryDescription";
/**
 * @hidden
 */
export let ArcGISOnlineMapImageryDescriptionMetadata = /*@__PURE__*/ (() => {
    class ArcGISOnlineMapImageryDescriptionMetadata extends Base {
        static b(a) {
            if (ArcGISOnlineMapImageryDescriptionMetadata.a == null) {
                ArcGISOnlineMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ArcGISOnlineMapImageryDescriptionMetadata.c(ArcGISOnlineMapImageryDescriptionMetadata.a);
            }
            if (a.j(ArcGISOnlineMapImageryDescriptionMetadata.a)) {
                return;
            }
            a.y(ArcGISOnlineMapImageryDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapImageryDescriptionMetadata.c(a);
            a.item("MapServerUri", "String");
            a.item("UserName", "String");
            a.item("Password", "String");
            a.item("UserToken", "String");
            a.item("IsMapPublic", "Boolean");
            a.item("DefaultTokenTimeout", "Number:int");
            a.item("TokenGenerationEndPoint", "String");
            a.item("RefererUri", "String");
        }
        static d(a) {
            ArcGISOnlineMapImageryDescriptionMetadata.b(a);
            a.aa("ArcGISOnlineMapImagery", () => new ArcGISOnlineMapImageryDescription());
            a.z("ArcGISOnlineMapImagery", ArcGISOnlineMapImageryDescriptionMetadata.a);
        }
    }
    ArcGISOnlineMapImageryDescriptionMetadata.$t = /*@__PURE__*/ markType(ArcGISOnlineMapImageryDescriptionMetadata, 'ArcGISOnlineMapImageryDescriptionMetadata');
    ArcGISOnlineMapImageryDescriptionMetadata.a = null;
    return ArcGISOnlineMapImageryDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ArcGISOnlineMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { ArcGISOnlineMapImageryDescription } from "./ArcGISOnlineMapImageryDescription";
/**
 * @hidden
 */
export let ArcGISOnlineMapImageryDescriptionMetadata = /*@__PURE__*/ (() => {
    class ArcGISOnlineMapImageryDescriptionMetadata extends Base {
        static b(a) {
            if (ArcGISOnlineMapImageryDescriptionMetadata.a == null) {
                ArcGISOnlineMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ArcGISOnlineMapImageryDescriptionMetadata.c(ArcGISOnlineMapImageryDescriptionMetadata.a);
            }
            if (a.k(ArcGISOnlineMapImageryDescriptionMetadata.a)) {
                return;
            }
            a.aa(ArcGISOnlineMapImageryDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapImageryDescriptionMetadata.c(a);
            a.item("MapServerUri", "String");
            a.item("UserName", "String");
            a.item("Password", "String");
            a.item("UserToken", "String");
            a.item("IsMapPublic", "Boolean");
            a.item("DefaultTokenTimeout", "Number:int");
            a.item("TokenGenerationEndPoint", "String");
            a.item("RefererUri", "String");
        }
        static d(a) {
            ArcGISOnlineMapImageryDescriptionMetadata.b(a);
            a.ac("ArcGISOnlineMapImagery", () => new ArcGISOnlineMapImageryDescription());
            a.ab("ArcGISOnlineMapImagery", ArcGISOnlineMapImageryDescriptionMetadata.a);
        }
    }
    ArcGISOnlineMapImageryDescriptionMetadata.$t = /*@__PURE__*/ markType(ArcGISOnlineMapImageryDescriptionMetadata, 'ArcGISOnlineMapImageryDescriptionMetadata');
    ArcGISOnlineMapImageryDescriptionMetadata.a = null;
    return ArcGISOnlineMapImageryDescriptionMetadata;
})();
